"use strict";(self.webpackChunk_unfolded_jupyter_map_sdk=self.webpackChunk_unfolded_jupyter_map_sdk||[]).push([[747],{747:(n,e,t)=>{t.r(e),t.d(e,{MapError:()=>a,createMap:()=>i});var a=class extends Error{constructor(n){super(n),Object.setPrototypeOf(this,a.prototype)}};async function i(n={},e){let t,a="https://studio.unfolded.ai/studio-bundle.js";(function(n){return"object"==typeof n&&null!==n&&"url"in n&&("string"==typeof n.namespace||typeof n.namespace>"u")})(e)&&(a=e.url,t=e.namespace);let{showPlaceholder:i=!0}=n;return n.container&&i&&(n.container.innerHTML='<div class="map-placeholder" style="width: 100%; position: absolute; top: 0; left: 0; right: 0; height: 100%">\n  <div style="margin-top: 15vh; display: flex; flex-direction: row; justify-content: center">\n    <div>\n      <svg viewBox="0 0 202 175" width="40px" height="40px" style="fill: currentcolor">\n        <style>\n          @keyframes pulse {\n            0% {\n              opacity: 0.2;\n            }\n            20% {\n              opacity: 0.4;\n            }\n            100% {\n              opacity: 1;\n            }\n          }\n          path {\n            animation: pulse 2.4s infinite;\n          }\n          path:nth-child(1) {\n            animation-delay: 0s;\n          }\n          path:nth-child(2) {\n            animation-delay: 0.4s;\n          }\n          path:nth-child(3) {\n            animation-delay: 0.8s;\n          }\n          path:nth-child(4) {\n            animation-delay: 1.2s;\n          }\n          path:nth-child(5) {\n            animation-delay: 1.6s;\n          }\n        </style>\n        <path\n          d="M100.6 87.13 50.31 174.25 0 87.13 50.3 0 67.94 30.54 35.27 87.13 49.69 112.11 82.36 55.52 100.6 87.13Z"\n          fill="#1e4dff"\n        />\n        <path d="M67.94 30.54 168.61 30.54 150.98 0 50.3 0 67.94 30.54" fill="#5cbbff" />\n        <path d="M201.22,87.13l0-.06L183,55.52H82.36L100.6,87.13Z" fill="#5cbbff" />\n        <path d="M164.67,87.12,146,119.66l55.21-32.54Z" fill="#090b66" />\n        <path\n          d="M201.21 87.15 150.91 174.25 132.7 142.71 146.07 119.64 201.21 87.15Z"\n          fill="#5558db"\n        />\n      </svg>\n    </div>\n  </div>\n</div>'),(await function(n){let{url:e,namespace:t="Unfolded.SDK.v1"}=n,a=`${e}::${t}`;if(void 0!==l[a])return l[a];let i=document.createElement("script");return l[a]=new Promise(((n,a)=>{i.onload=async()=>{let i=function(n,e){return e.split(".").reduce(((n,e)=>{if(n&&"object"==typeof n&&e in n)return n[e]}),n)}(globalThis,t)?.createMap;i?n(i):a(new Error(`Failed to load map interface from ${e}`))},i.onerror=a})),i.type="text/javascript",i.src=e,document.querySelector("head")?.appendChild(i),l[a]}({url:a,namespace:t}))(n)}var l={}}}]);